@@ -310,15 +310,32 @@ void tileEngineProcessMouse(int uiElemPressed) {
             canvas.dy *= 0.2;
         }
     }
+}
 
-    canvas.x += canvas.dx;
-    canvas.y += canvas.dy;
+void tileEngineProcessAccelerometer() {
+    if (canvas.viewMode == VIEW_2D) {
+        if (abs(accelerometer.x) > 70) {
+            canvas.dx += accelerometer.x / 1000.0;
+        }
+        if (abs(accelerometer.y) > 70) {
+            canvas.dy += accelerometer.y / 1000.0;
+        }
+    } else {
+        if (abs(accelerometer.y) > 70) {
+            canvas.dx += accelerometer.y / 1000.0 * sin(canvas.rotz * M_PI / 180.0);
+            canvas.dy += accelerometer.y / 1000.0 * cos(canvas.rotz * M_PI / 180.0);
+        }
+        canvas.drotz += accelerometer.x / 2000.0;
+    }
 }
 
 void tileEngineUpdateCoordinates() {
     //int zoomChange = (int) round(log2((double) canvas.scale));
     int zoomChange = 0;
 
+    canvas.x += canvas.dx;
+    canvas.y += canvas.dy;
+
     if (followingMypos) {
         if (device -> fix -> fields | LOCATION_GPS_DEVICE_LATLONG_SET) {
             GLfloat x, y;
